# -*- mode: python; coding: utf-8; -*-

from django.contrib import admin
from django.contrib.auth.models import User
from django.conf import settings

from blog.models import Post


class PostAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('name', )}
    list_display = ('name', 'date', 'author', 'enable_comments', 'comments_open', 'is_draft', 'site', 'view_link')
    search_fields = ('name', 'text')
    list_filter = ('date', 'is_draft', 'site')
    fieldsets = (
        (None, {'fields': (('author', 'site'), ('name', 'slug'), 'tags', 'text', 'render_method', 'date', ('is_draft', 'enable_comments'))}),
        )

    class Media:
        if settings.WYSIWYG_ENABLE:
            js = (
                'http://ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js',
                settings.STATIC_URL + 'js/wymeditor/jquery.wymeditor.pack.js',
                '/' + settings.BLOG_URLCONF_ROOT + 'wysiwyg_js/',
                )
        elif settings.RENDER_METHOD in ('html', 'markdown', 'rst'):
            js = (settings.STATIC_URL + 'js/postimage.js', )

    def queryset(self, request):
        qs = super(PostAdmin, self).queryset(request)
        if not request.user.is_superuser:
            qs = qs.filter(author=request.user)
        return qs

    def get_form(self, request, obj=None, **kwargs):
        '''
        Overwrite get_form to select the currently logged in user as the author
        '''
        form = super(PostAdmin, self).get_form(request, obj, **kwargs)
        f = form.base_fields['author']
        f.initial = request.user.pk
        if request.user.is_superuser:
            f.queryset = User.objects.filter(is_staff=True)
        else:
            f.queryset = User.objects.filter(pk=request.user.pk)
        form.base_fields['site'].initial = settings.SITE_ID
        return form

admin.site.register(Post, PostAdmin)
